strict property
When true, evaluating a selector that cannot be decided with the
information available throws UndecidableSelectorError instead of
silently returning false.
Implementation
final bool strict;
When true, evaluating a selector that cannot be decided with the
information available throws UndecidableSelectorError instead of
silently returning false.
final bool strict;