asFunctionWith method
Returns this selector as a predicate bound to context.
Implementation
Selector asFunctionWith(MatchContext context) =>
(node) => matchWith(node, context);
Returns this selector as a predicate bound to context.
Selector asFunctionWith(MatchContext context) =>
(node) => matchWith(node, context);