Selector typedef
Selector =
bool Function(Node)
A function that tests whether a node matches a selector.
Implementation
typedef Selector = bool Function(Node);
A function that tests whether a node matches a selector.
typedef Selector = bool Function(Node);