TargetPseudoClass class
:target — the element referenced by the URL fragment.
- Inheritance
-
- Object
- Sel
- PseudoClassSelector
- TargetPseudoClass
- Available extensions
Constructors
- TargetPseudoClass()
-
Creates a
:targetselector.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- pseudoElement → String
-
The pseudo-element attached to this selector, or
''if there is none.no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- specificity → Specificity
-
The specificity of this selector as an
(a, b, c)triple.no setterinherited - support → MatchSupport
-
How well this selector can be evaluated. See MatchSupport.
no setteroverride
-
undecidableParts
→ Set<
String> -
The names of any parts of this selector that are not fully decidable.
no setteroverride
Methods
-
asFunction(
) → Selector -
Available on Sel, provided by the SelAdapter extension
Returns this selector as a callable predicate. -
asFunctionWith(
MatchContext context) → Selector -
Available on Sel, provided by the SelAdapter extension
Returns this selector as a predicate bound tocontext. -
match(
Node node) → bool -
Whether
nodematches this selector, using no runtime context.inherited -
matchElement(
Element element, MatchContext context) → bool -
Whether
elementmatches. Implemented by concrete selectors.override -
matchWith(
Node node, MatchContext context) → bool -
Whether
nodematches, using the runtime facts incontext.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
The CSS text of this selector.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited